package org.malai.example.drawingEditor.action;

import org.malai.action.Action;

public class AddShape extends Action {

	public AddShape() {
		// TODO Auto-generated constructor stub
	}

	@Override
	public boolean canDo() {
		// TODO Auto-generated method stub
		return false;
	}

	@Override
	protected void doActionBody() {
		// TODO Auto-generated method stub

	}

	@Override
	public boolean isRegisterable() {
		// TODO Auto-generated method stub
		return false;
	}

}
