package org.malai.error;

/**
 * Exception launched when an application try to get Wiimote(s)
 * but there is/are not available.
 * 
 * @author Maxime Lorant
 *
 */
public class AttachWiimoteException extends Exception {
	
	private static final long serialVersionUID = 8360005812309558050L;

}
