package org.malai.ex.draw.ui;

import javafx.fxml.FXML;
import javafx.scene.canvas.Canvas;
import javafx.scene.control.MenuBar;
import javafx.scene.control.SplitPane;

public class Controler {
	@FXML public MenuBar menuBar;
	@FXML public SplitPane splitPane;
	@FXML public Canvas canvas;
	
	public Controler() {
		super();
	}
}
