package test.org.malai.interaction;

import org.malai.interaction.InteractionImpl;

public class InteractionMock extends InteractionImpl {
	public InteractionMock() {
		super();
	}


	@Override
	protected void initStateMachine() {
		//
	}


	@Override
	protected void processEvent(final Event event) {
		//
	}
}
