/**
 */
package org.malai.interaction.impl;

import org.eclipse.emf.ecore.EClass;

import org.malai.interaction.InteractionPackage;
import org.malai.interaction.TerminalState;

/**
 * <!-- begin-user-doc -->
 * An implementation of the model object '<em><b>Terminal State</b></em>'.
 * <!-- end-user-doc -->
 * <p>
 * </p>
 *
 * @generated
 */
public class TerminalStateImpl extends StateImpl implements TerminalState {
	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected TerminalStateImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	protected EClass eStaticClass() {
		return InteractionPackage.Literals.TERMINAL_STATE;
	}

} //TerminalStateImpl
