/**
 */
package org.malai.widget;


/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Multi Line List</b></em>'.
 * <!-- end-user-doc -->
 *
 *
 * @see org.malai.widget.WidgetPackage#getMultiLineList()
 * @model
 * @generated
 */
public interface MultiLineList extends ListWidget {
} // MultiLineList
