/**
 */
package org.malai.widget.impl;

import org.eclipse.emf.ecore.EClass;

import org.malai.widget.Button;
import org.malai.widget.WidgetPackage;

/**
 * <!-- begin-user-doc -->
 * An implementation of the model object '<em><b>Button</b></em>'.
 * <!-- end-user-doc -->
 * <p>
 * </p>
 *
 * @generated
 */
public class ButtonImpl extends ButtonWidgetImpl implements Button {
	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected ButtonImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	protected EClass eStaticClass() {
		return WidgetPackage.Literals.BUTTON;
	}

} //ButtonImpl
